@@ -10,8 +10,7 @@
 # sys.setrecursionlimit(n)
 
 from satnogsdbapiclient.model.artifact import Artifact
-from satnogsdbapiclient.model.blank_enum import BlankEnum
-from satnogsdbapiclient.model.coordination_enum import CoordinationEnum
+from satnogsdbapiclient.model.iaru_coordination_enum import IaruCoordinationEnum
 from satnogsdbapiclient.model.latest_tle_set import LatestTleSet
 from satnogsdbapiclient.model.mode import Mode
 from satnogsdbapiclient.model.new_artifact import NewArtifact
